==> EntitySyncer-0.0.7-sources.jar: org/openzen/entitysyncer/live/any/LiveAny.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.any;

import java.util.UUID;
import org.openzen.entitysyncer.live.LiveBool;
import org.openzen.entitysyncer.live.LiveByteArray;
import org.openzen.entitysyncer.live.LiveDouble;
import org.openzen.entitysyncer.live.LiveFloat;
import org.openzen.entitysyncer.live.LiveInt;
import org.openzen.entitysyncer.live.LiveLong;
import org.openzen.entitysyncer.live.LiveObject;
import org.openzen.entitysyncer.live.LiveObjectList;
import org.openzen.entitysyncer.live.LiveString;
import org.openzen.entitysyncer.live.LiveTranslatableString;
import org.openzen.entitysyncer.live.LiveUUID;
import org.openzen.entitysyncer.live.LiveValue;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public interface LiveAny extends LiveValue {
	public LiveBool asBool();
	
	public boolean asBoolValue();
	
	public LiveInt asInt();
	
	public int asIntValue();
	
	public LiveLong asLong();
	
	public long asLongValue();
	
	public LiveFloat asFloat();
	
	public float asFloatValue();
	
	public LiveDouble asDouble();
	
	public double asDoubleValue();
	
	public LiveString asString();
	
	public String asStringValue();
	
	public LiveUUID asUUID();
	
	public UUID asUUIDValue();
	
	public LiveByteArray asByteArray();
	
	public byte[] asByteArrayValue();
	
	public LiveObject<?> asObject();
	
	public StructuredObject asObjectValue();
	
	public LiveObjectList<?> asObjectList();
	
	public LiveTranslatableString asTranslatableString();
}

==> EntitySyncer-0.0.14-sources.jar: org/openzen/entitysyncer/live/any/LiveAny.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.any;

import java.util.UUID;
import org.openzen.entitysyncer.live.LiveBool;
import org.openzen.entitysyncer.live.LiveByteArray;
import org.openzen.entitysyncer.live.LiveDouble;
import org.openzen.entitysyncer.live.LiveFloat;
import org.openzen.entitysyncer.live.LiveInt;
import org.openzen.entitysyncer.live.LiveLong;
import org.openzen.entitysyncer.live.LiveObject;
import org.openzen.entitysyncer.live.LiveObjectList;
import org.openzen.entitysyncer.live.LiveString;
import org.openzen.entitysyncer.live.LiveUUID;
import org.openzen.entitysyncer.live.LiveValue;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public interface LiveAny extends LiveValue {
	public LiveBool asBool();
	
	public boolean asBoolValue();
	
	public LiveInt asInt();
	
	public int asIntValue();
	
	public LiveLong asLong();
	
	public long asLongValue();
	
	public LiveFloat asFloat();
	
	public float asFloatValue();
	
	public LiveDouble asDouble();
	
	public double asDoubleValue();
	
	public LiveString asString();
	
	public String asStringValue();
	
	public LiveUUID asUUID();
	
	public UUID asUUIDValue();
	
	public LiveByteArray asByteArray();
	
	public byte[] asByteArrayValue();
	
	public LiveObject<?> asObject();
	
	public StructuredObject asObjectValue();
	
	public LiveObjectList<?> asObjectList();
	
	public <T extends LiveStruct> T asStruct(Class<T> cls);
}
